@@ -182,6 +182,10 @@ class VerifyToken:
         is_all_data = False
         user = self.user_db.find_docu_by_id(id=self.uid)  # 查询用户对应的角色数据
         role_name_list = user['role_name']  # 用户包含的所有角色名称
+        # 合并多角色权限
+        permission_list = []
+        is_all_data_list = []
+        # 遍历角色权限数据
         for role_name in role_name_list:
             # 查询角色包含的权限集合，role_name + center_name + permission_name 不重复
             roles = self.role_db.find_docu(find_dict={'role_name': role_name,
@@ -190,8 +194,15 @@ class VerifyToken:
                                                       },
                                            many=False)
             if roles:
-                permission_list = roles[0]['permission_status']  # list类型
-                is_all_data = roles[0]['is_all_data']  # 是否开放全部数据
+                permission_list.extend(roles[0]['permission_status'])  # list类型
+                is_all_data_list.append(roles[0]['is_all_data'])  # 是否开放全部数据
+        permission_list = list(set(permission_list))  # 权限值去重
+        is_all_data_list = list(set(is_all_data_list))  # 数据权限去重
+        if is_all_data_list == [True]:
+            is_all_data = True  # 仅全部True为True
+        else:
+            is_all_data = False  # 安全考虑，含False都为False
+        # 结束合并角色权限
         if ([0] == permission_list) or (not permission_list):
             handle_abnormal(
                 message='无 "{0}-{1}" 的访问权限({2})'.format(
